summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasline_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasline_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasline_imp.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kjsembed/qtbindings/qcanvasline_imp.cpp b/kjsembed/qtbindings/qcanvasline_imp.cpp
index 6ddf7c5d..429321f3 100644
--- a/kjsembed/qtbindings/qcanvasline_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasline_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvasline_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -74,7 +74,7 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -87,25 +87,25 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasLine pointer from an Object.
*/
-QCanvasLine *QCanvasLineImp::toQCanvasLine( KJS::Object &self )
+TQCanvasLine *QCanvasLineImp::toQCanvasLine( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasLine *>( obj );
+ return dynamic_cast<TQCanvasLine *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasLine" )
+ if ( op->typeName() != "TQCanvasLine" )
return 0;
- return op->toNative<QCanvasLine>();
+ return op->toNative<TQCanvasLine>();
}
/**
@@ -123,7 +123,7 @@ KJS::Object QCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &ar
break;
}
- QString msg = i18n("QCanvasLineCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasLineCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -131,15 +131,15 @@ KJS::Object QCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object QCanvasLineImp::QCanvasLine_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the QCanvasLine object
+ // We should now create an instance of the TQCanvasLine object
- QCanvasLine *ret = new QCanvasLine(
+ TQCanvasLine *ret = new TQCanvasLine(
arg0 );
@@ -180,7 +180,7 @@ KJS::Value QCanvasLineImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- QString msg = i18n( "QCanvasLineImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasLineImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -207,7 +207,7 @@ KJS::Value QCanvasLineImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPoint ret;
+ TQPoint ret;
ret = instance->startPoint( );
return convertToValue( exec, ret );
@@ -216,7 +216,7 @@ KJS::Value QCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QCanvasLineImp::endPoint_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPoint ret;
+ TQPoint ret;
ret = instance->endPoint( );
return convertToValue( exec, ret );
@@ -238,7 +238,7 @@ KJS::Value QCanvasLineImp::setPen_7( KJS::ExecState *exec, KJS::Object &obj, con
// Unsupported parameter QPen
return KJS::Value();
- QPen arg0; // Dummy
+ TQPen arg0; // Dummy
instance->setPen(
arg0 );
@@ -87,25 +87,25 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasLine pointer from an Object.
+ * Extract a TQCanvasLine pointer from an Object.
*/
@@ -131,15 +131,15 @@ KJS::Object QCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object QCanvasLineImp::QCanvasLine_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();